# frozen_string_literal: true

require 'cht-lib-fabric/crn'
require 'i18n'

module FeatureConfig
  module Actions
    module ChecksTenantCrnAuthz
      # Get the parsed tenant from the request, or fail and return nil
      #
      # @return [nil, Platform::CRN::Tenant]
      #   Nil if the request failed (will also modify request context with a failure)
      def authorized_crn_from_context
        crn = ::Platform::CRN.from_s context.params[:tenant]

        if correct_tenant?(crn)
          crn
        else
          logger.error("Wrong customer ID in tenant parameter")
          context.fail!(error: I18n.t("error_codes.#{::FeatureConfig::ErrorCodes::NOT_AUTHORIZED}"))
          nil
        end
      rescue Platform::InvalidCRNError => ex
        logger.error("Invalid CRN")
        logger.debug(ex)
        context.fail!(error: I18n.t("error_codes.#{::FeatureConfig::ErrorCodes::INVALID_CRN}"))
        nil
      end

      private

      # Does the request tenant match the access token tenant?
      #
      # Eventually we should use the authorization service for this check.
      def correct_tenant?(crn)
        context.request.current_customer == crn.customer
      end
    end
  end
end
