# frozen_string_literal: true

require 'import'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/tasks/actionable'

module FeatureConfig
  module Actions
    # Get data about settings shared across all customers
    class GlobalSettingsEnabled
      include ::Platform::Tasks::Actionable
      include Import[
        :inflector,
        'setting_def.global_setting'
      ]

      def call
          all_settings = global_setting['available'].each_with_object({}) do |setting_name, acc|
            acc[setting_name] = ENV[setting_name.upcase] ? true : false
          end

        context.globalSetting =
          all_settings
          .keys
          .select { |k| all_settings[k] }.map { |f| inflector.upper_underscore(f.to_s) }
      end
    end
  end
end
