# frozen_string_literal: true

require 'import'
require 'feature_config/consumers/application_consumer'
require 'feature_config/tasks/legacy_cache'

module FeatureConfig
  module Consumers
    class Customer < ApplicationConsumer
      include Import[:logger, :alert]
      def consume
        logger.debug { "processing customer change message. params: #{params.to_h}" }
        crn = nil
        # action is valid for any message type
        action = params['action'].downcase

        # Only process create events, for delete we keep their records around
        # anyways and they lose access, the normal rake task schedule will take
        # care of the cleanup as needed
        case action
        when 'create'
          crn = ::Platform::CRN.from_s(params['crn'])
          customer_id = crn.customer

          logger.info("Processing new customer #{customer_id} for cache updates")

          # Invoke the rake task for a single customer to seed the caches
          # Note: This doesn't execute the path where the mass cleanup of 
          # redis keys is done
          ::FeatureConfig::Tasks::LegacyCache.new.do_customer_with_shard_lookup(customer_id)

          logger.info("Customer #{customer_id} onboarded and cache(s) updated")
        end
      rescue => ex
        logger.error { "Unable to onboard customer and refresh caches #{ex}" }
        alert.exception(
          ex,
          params: params.to_h,
          customer_id: (defined?(crn) && !crn.nil?) ? crn.customer : nil
        )
        raise
      end
    end
  end
end
