# frozen_string_literal: true

require 'graphql'
require 'feature_config/actions'
require 'cht-lib-fabric/helpers/graphql/action_resolver'
require 'container' # or require 'import'
require 'cht-lib-fabric/helpers/graphql/metric_tracing'

GRAPHQL_RESOLVERS = {
  'resolve_type' => lambda { |_type, obj, _ctx|
    ::FeatureConfig::Schema.types[obj.class.name.demodulize]
  },
  "Query" => {
    "globalSettingsEnabled" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::FeatureConfig::Actions::GlobalSettingsEnabled, :globalSetting
    ),
    "customerInfo" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::FeatureConfig::Actions::CustomerInfo, :customerInfo
    ),
    "customerSettingsEnabled" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::FeatureConfig::Actions::CustomerSettingsEnabled, :customerSetting
    ),
    "customerExtendedSettingsEnabled" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::FeatureConfig::Actions::CustomerExtendedSettingsEnabled, :customerExtendedSetting
    ),
    "_service" => ::Platform::Helpers::GraphQL::ActionResolver.new(
      ::FeatureConfig::Actions::Service, :service
    )
  }
}.freeze

module FeatureConfig
  Schema = GraphQL::Schema.from_definition(
    File.read("app/feature_config/graphql/schema.graphql"),
    default_resolve: GRAPHQL_RESOLVERS,
    using: {
      ::Platform::Helpers::GraphQL::MetricTracing => {
        client: Application[:wavefront]
      }
    }
  )
end
